@@ -467,13 +467,15 @@ def to_hedged_euro(weight_data = None, rates_data = None):
 
     data['indice_usd'] = data['indice']
 
-    data['p_n_l_dollars'] = data['indice_usd'] .pct_change()
+    data['return_dollars'] = data['indice_usd'] .pct_change()
 
     data['indice_eur'] = data['indice_usd']/data['EUR-USD']
 
-    data['indice_hedged_eur'] = data['indice_eur'] * data['EUR-USD'] / data['previous_EUR-USD']
+    data['return_eurs'] = data['indice_eur'].pct_change()
 
-    data['p_n_l_eurs'] = data['indice_eur'].pct_change()
+    data['return_hedged_eurs'] = data['return_dollars'] * data['previous_EUR-USD'] / data['EUR-USD']
+
+    data['indice_hedged_eur'] = metrics.from_ret_to_price(data['return_hedged_eurs'].fillna(0.).values , 100.)
 
     data['indice'] = data['indice_hedged_eur']
     return data
